==> tpy-0.1.7-py2.py3-none-any.whl: tpy/tmux.py <==
import os

import libtmux

server = libtmux.Server()


def execute(cmd, session_name, window_name, reset_window=True, dir=None, dry=False):
    session = get_session(session_name)
    window = get_window(session, window_name, reset=reset_window)
    pane = get_pane_attached(window)
    pane.cmd("send-keys", change_dir(cmd, dir))
    if not args.dry:
        pane.cmd("send-keys", "enter")


def execute_prev(session_name, window_name, reset_window=True, cursor_up=1, dry=False):
    session = get_session(session_name)
    window = get_window(session, window_name, reset=reset_window)
    pane = get_pane_attached(window)
    for _ in range(cursor_up):
        pane.cmd("send-keys", "up")
    if not args.dry:
        pane.cmd("send-keys", "enter")


def get_session(session_name, create=True):
    if server.has_session(session_name):
        session = server.find_where({"session_name": session_name})
    else:
        if create:
            session = server.new_session(session_name)
        else:
            raise RuntimeError(f"Session {session_name} does not exist")
    return session


def get_window(session, window_name=None, reset=False):
    if window_name is None:
        window = session.attached_window
        if reset:
            kill_id = window.id
            window = session.new_window(attach=True)
            session.kill_window(kill_id)
        return window

    for window in session.list_windows():
        if window.name == window_name:
            if not reset:
                return window
            else:
                session.kill_window(window_name)

    window = session.new_window(attach=True, window_name=window_name)

    return window


def get_pane_attached(window):
    return window.attached_pane


def change_dir(cmd, dir=None):
    if dir is not None:
        cmd = "cd " + os.path.dirname(os.path.abspath(dir)) + "; "+ cmd
    return cmd

==> tpy-0.1.8-py2.py3-none-any.whl: tpy/tmux.py <==
import os

import libtmux

server = libtmux.Server()


def execute(cmd, session_name, window_name, reset=True, dir=None, dry=False):
    session = get_session(session_name)
    window = get_window(session, window_name, reset=reset)
    pane = get_pane_attached(window, reset=False)
    pane.cmd("send-keys", change_dir(cmd, dir))
    if not dry:
        pane.cmd("send-keys", "enter")


def execute_prev(session_name, window_name, reset=True, cursor_up=1, dry=False):
    session = get_session(session_name)
    window = get_window(session, window_name, reset=reset)
    pane = get_pane_attached(window, reset=False)
    for _ in range(cursor_up):
        pane.cmd("send-keys", "up")
    if not dry:
        pane.cmd("send-keys", "enter")


def get_session(session_name, create=True):
    if server.has_session(session_name):
        session = server.find_where({"session_name": session_name})
    else:
        if create:
            session = server.new_session(session_name)
        else:
            raise RuntimeError(f"Session {session_name} does not exist")
    return session


def get_window(session, window_name=None, reset=False):
    if window_name is None:
        window = session.attached_window
        if reset:
            kill_id = window.id
            window = session.new_window(attach=True)
            session.kill_window(kill_id)
        return window

    for window in session.list_windows():
        if window.name == window_name:
            if not reset:
                return window
            else:
                session.kill_window(window_name)

    window = session.new_window(attach=True, window_name=window_name)

    return window


def get_pane_attached(window, reset=False):
    pane = window.attached_pane
    if reset:
        pane.clear()
    return pane


def change_dir(cmd, dir=None):
    if dir is not None:
        cmd = "cd " + os.path.dirname(os.path.abspath(dir)) + "; "+ cmd
    return cmd
